# *stamina*: Production-grade Retries Made Easy

Release **{sub-ref}`release`**  ([What's new?](changelog))

```{include} ../README.md
:start-after: "## Production-grade Retries Made Easy"
:end-before: "For example:"
```

## User's Guide

```{toctree}
:maxdepth: 2

tutorial
api
security
```


## Project Information

```{include} ../README.md
:start-after: "## Project Information"
```


```{toctree}
:hidden: true

changelog
```
